HIRISE_api.models.Ensemble_Models — HIRISE_api documentation

# HIRISE_api.models.Ensemble_Models

Functions

`ensemble_model`(encoded_data, labels, ...[, ...]) |
`evaluate_model`(model, translation_dataframe, ...) | Function that uses cross-validation and evalutes the stacking model.
`get_models`([discovery]) | Function that defines specified models as an input to the ensemble model.
`get_stacking`([discovery, all_models]) | Function that stacks specified models together as an input to the ensemble model.

Classes

`AgglomerativeClusteringWrapper`([n_clusters, ...]) |
`DBSCANWrapper`([eps, min_samples, metric, ...]) |
`HDBSCANWrapper`([min_cluster_size, ...]) |
`OpticsWrapper`(*[, min_samples, max_eps, ...]) |